/**
******************************************************************************
* @file    IRPyro_UT_HL.c
* @author  _KEMET, Ltd
* @date    March 2018
* @version Release 1.0.6
* @copyright (c) 2018 _KEMET, Ltd
* @brief   High Level Unit Testing module
******************************************************************************
   @attention <h2><center>&copy; COPYRIGHT 2018 _KEMET, Ltd</center></h2>

   @verbatim
    Copyright (c) 2018, _KEMET, Ltd
    All rights reserved.

    THIS SOFTWARE IS PROVIDED BY _KEMET, Ltd ''AS IS'' AND ANY
    EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
    WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
    DISCLAIMED. IN NO EVENT SHALL _KEMET, Ltd BE LIABLE FOR ANY
    DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
    (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
    LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
    ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
    (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
   @endverbatim
******************************************************************************
*/
/* Includes ------------------------------------------------------------------*/
#include "IRPyro_UT.h"
void test01(void);
void test02(void);
void test03(void);
void test04(void);
void test05(void);
void test06(void);
void test07(void);
void test08(void);
void test09(void);
void test10(void);
void test11(void);
void test12(void);
void test13(void);
void test14(void);
void test15(void);
void test16(void);
/** @defgroup IRPyroAPI_UnitTest_HL High level unit test module
 * @brief Configure the IRPyro sensors to test and calls the functions defined in IRPyroUT.c
 * @{
 */
/** @defgroup UT_01_IRPyro Main function
 * @brief Calls the product verification plan units
 *        Each function validates a point of the product verification plan
 * @note Refer to PSVP017 (product verification specification) document on the engineering section.
 * @{
 */
/**
 * @brief unit testing main program.
  */
int main()
{
    /*-------------------------- board setup ---------------------------------*/
    Micro_controller_template_init();
    // turn off all CS lines
    IRPyro_demo_board(0);
    /*-------------------------- start test ----------------------------------*/
    /*Single Sensor Test */
//    test01(); // 01 Initialize a single device for INTERRUPT CONFIGURATION
//    test02(); // 02 Initialize a single device for POLLED CONFIGURATION
//    test03(); // 03 Initialize a single device for DAISY CHAIN CONFIGURATION
//    test07(); // 07 READ DATA FROM A SINGLE SENSOR and detect frames missing with the sensor CONFIGURED FOR INTERRUPT. <<---------- single sensor performance test
//    test08(); // 08 READ DATA FROM A SINGLE SENSOR and detect frames missing with the sensor CONFIGURED FOR POLLED
//  ====      test09(); // 09 READ DATA FROM A SINGLE SENSOR and detect frames missing with the sensor CONFIGURED FOR DAISY CHAIN
//    test14(); // 14 Change sensor POWER CONFIGURATION
//    test15(); // 15 Configure sensor WAKE UP EVENT, SEND TO SLEEP, DETECT WAKE UP
//    test16(); // 16 Change PARAMETERS on the fly

    /*Multiple Sensor Test */
//    test04(); // 04 Initialize multiple devices for INTERRUPT CONFIGURATION
//    test05(); // 05 Initialize multiple devices for POLLED CONFIGURATION
//    test06(); // 06 Initialize multiple devices for DAISY CHAIN CONFIGURATION
//    test10(); // 10 READ DATA FROM MULTIPLE SENSORS and detect frames missing with the sensors CONFIGURED FOR INTERRUPT. <<---------- multiple sensor performance test
//    test11(); // 11 READ DATA FROM MULTIPLE SENSORS and detect frames missing with the sensors CONFIGURED FOR POLLED
//    test12(); // 12 READ DATA FROM MULTIPLE SENSORS and detect frames missing with the sensors CONFIGURED FOR DAISY CHAIN
}
/** end of main program
 * @}
 */
/** @defgroup ver_plan Verification plan functions
 * @brief each function configures the required data structures to pass to the
 *        unit test functions
 * @{
 */
/**
 * @brief Data structure for single device with INTERRUPT enabled is defined, sent to the IRPyro sensor and then read back again.
 */
void test01(void)
{
    /*------------------ Memory allocation, initialization-------------------*/
    IRPyro_sensor_device_type IRPyro_single_sensor = {0}; // Instance of sensor
    /*-------------------Physical Location ----------------------------------*/
    IRPyro_single_sensor.INT_Port = 1;
    IRPyro_single_sensor.CS_Port  = 2;
    IRPyro_single_sensor.CS_Pin   = 1;
    IRPyro_single_sensor.INT_Pin  = 4;
    /*-------------------Test configuration ---------------------------------*/
    IRPyro_single_sensor.read_mode = 0;                   // INTERRUPT CONFIGURATION
    IRPyro_single_sensor.address   = 0x08;                // I2C address to configure
    IRPyro_single_sensor.number_of_active_channels = 1;   // configures channel 2 for streaming
    /*-------------------------- board setup ---------------------------------*/
    IRPyro_demo_board(0);
    UART_PutString(USART2, (uint8_t*)"01 Initialize a single device for INTERRUPT CONFIGURATION \n\n");
    ut01_single_sensor_init(&IRPyro_single_sensor);
}
/**
 * @brief Data structure for single device with POLLED CONFIGURATION enabled is defined, sent to the IRPyro sensor and then read back again.
 */
void test02(void)
{
    /*------------------ Memory allocation, initialization-------------------*/
    IRPyro_sensor_device_type IRPyro_single_sensor = {0}; // Instance of sensor
    /*-------------------Physical Location ----------------------------------*/
    IRPyro_single_sensor.INT_Port = 1;
    IRPyro_single_sensor.CS_Port  = 2;
    IRPyro_single_sensor.CS_Pin   = 1;
    IRPyro_single_sensor.INT_Pin  = 4;
    /*-------------------Test configuration ---------------------------------*/
    IRPyro_single_sensor.read_mode = 1;                   // POLLED CONFIGURATION
    IRPyro_single_sensor.address   = 0x08;                // I2C address to configure
    IRPyro_single_sensor.number_of_active_channels = 1;   // configures channel 2 for streaming
    /*-------------------------- board setup ---------------------------------*/
    IRPyro_demo_board(0);
    UART_PutString(USART2, (uint8_t*)"02 Initialize a single device for POLLED CONFIGURATION \n");
    ut01_single_sensor_init(&IRPyro_single_sensor);
}
/**
 * @brief Data structure for single device with DAISY CHAIN CONFIGURATION enabled is defined, sent to the IRPyro sensor and then read back again.
 */
void test03(void)
{
    /*------------------ Memory allocation, initialization-------------------*/
    IRPyro_sensor_device_type IRPyro_single_sensor = {0}; // Instance of sensor
    /*-------------------Physical Location ----------------------------------*/
    IRPyro_single_sensor.INT_Port = 1;
    IRPyro_single_sensor.CS_Port  = 2;
    IRPyro_single_sensor.CS_Pin   = 1;
    IRPyro_single_sensor.INT_Pin  = 4;
    /*-------------------Test configuration ---------------------------------*/
    IRPyro_single_sensor.read_mode = 2;                   // DAISY CHAIN CONFIGURATION
    IRPyro_single_sensor.address   = 0x08;                // I2C address to configure
    IRPyro_single_sensor.number_of_active_channels = 1;   // configures channel 2 for streaming
    /*-------------------------- board setup ---------------------------------*/
    IRPyro_demo_board(0);
    UART_PutString(USART2, (uint8_t*)"03 Initialize a single device for DAISY CHAIN CONFIGURATION \n");
    ut01_single_sensor_init(&IRPyro_single_sensor);
}
/**
 * @brief A list of IRPyro devices is declared, all the devices interrupt enabled. The data structure is sent to the physical sensors, and then read back again.
 */
void test04(void)
{
    /*------------------- Memory allocation, initialization ------------------*/
    IRPyro_devices IRPyro_device = {0};
    /*----------------------- --- CONFIGURATION -----  -----------------------*/
    AFE_reg_type IRPyro_AFE_configuration =
    {
        .CLK_OUT = CLK_DISABLE,
        .INT  = INT_ENABLE
    };
    /*-----------------    ADDRESSES   ------------*/
    /* Assuming four sensors on an IRPyro Break out board or demo board*/
    IRPyro_device[0].INT_Port = 1;
    IRPyro_device[0].CS_Port  = 2;
    IRPyro_device[0].CS_Pin   = 1;
    IRPyro_device[0].INT_Pin  = 4;
    IRPyro_device[0].address  = 0x70;

    IRPyro_device[1].CS_Port  = 2;
    IRPyro_device[1].INT_Port = 1;
    IRPyro_device[1].CS_Pin   = 5;
    IRPyro_device[1].INT_Pin  = 5;
    IRPyro_device[1].address  = 0x69;

    IRPyro_device[2].CS_Port  = 2;
    IRPyro_device[2].INT_Port = 1;
    IRPyro_device[2].CS_Pin   = 4;
    IRPyro_device[2].INT_Pin  = 6;
    IRPyro_device[2].address  = 0x68;

    IRPyro_device[3].CS_Port  = 2;
    IRPyro_device[3].INT_Port = 1;
    IRPyro_device[3].CS_Pin   = 3;
    IRPyro_device[3].INT_Pin  = 7;
    IRPyro_device[3].address  = 0x67;

    /*-----------------    CONFIGURATION   ------------*/
    IRPyro_device[0].AFE_register    = IRPyro_AFE_configuration; // MASTER, INT, CLK DISABLED
    IRPyro_device[0].read_mode       = 0;
    IRPyro_device[0].number_of_active_channels = 1;              // configures channel 2 for streaming
    IRPyro_device[1].AFE_register    = IRPyro_AFE_configuration; // MASTER, INT, CLK DISABLED
    IRPyro_device[1].read_mode       = 0;
    IRPyro_device[1].number_of_active_channels = 1;              // configures channel 2 for streaming
    IRPyro_device[2].AFE_register    = IRPyro_AFE_configuration; // MASTER, INT, CLK DISABLED
    IRPyro_device[2].read_mode       = 0;
    IRPyro_device[2].number_of_active_channels = 1;              // configures channel 2 for streaming
    IRPyro_device[3].AFE_register    = IRPyro_AFE_configuration; // MASTER, INT, CLK DISABLED
    IRPyro_device[3].read_mode       = 0;
    IRPyro_device[3].number_of_active_channels = 1;              // configures channel 2 for streaming
    IRPyro_demo_board(0);
    UART_PutString(USART2, (uint8_t*)"04 Initialize multiple devices for INTERRUPT CONFIGURATION\n");
    ut02_multiple_sensor_init(IRPyro_device, 4);
}
/**
 * @brief A list of IRPyro devices is declared, all the devices with the interrupt disabled. The data structure is sent to the physical sensors, and then read back again.
 */
void test05(void)
{
    /*------------------- Memory allocation, initialization ------------------*/
    IRPyro_devices IRPyro_device = {0};
    /*----------------------- --- CONFIGURATION -----  -----------------------*/
    AFE_reg_type IRPyro_AFE_configuration =
    {
        .CLK_OUT = CLK_DISABLE,
        .INT  = INT_DISABLE
    };
    /*-----------------    ADDRESSES   ------------*/
    /* Assuming four sensors on an IRPyro Break out board or demo board*/
    IRPyro_device[0].INT_Port = 1;
    IRPyro_device[0].CS_Port  = 2;
    IRPyro_device[0].CS_Pin   = 1;
    IRPyro_device[0].INT_Pin  = 4;
    IRPyro_device[0].address  = 0x70;

    IRPyro_device[1].CS_Port  = 2;
    IRPyro_device[1].INT_Port = 1;
    IRPyro_device[1].CS_Pin   = 5;
    IRPyro_device[1].INT_Pin  = 5;
    IRPyro_device[1].address  = 0x69;

    IRPyro_device[2].CS_Port  = 2;
    IRPyro_device[2].INT_Port = 1;
    IRPyro_device[2].CS_Pin   = 4;
    IRPyro_device[2].INT_Pin  = 6;
    IRPyro_device[2].address  = 0x68;

    IRPyro_device[3].CS_Port  = 2;
    IRPyro_device[3].INT_Port = 1;
    IRPyro_device[3].CS_Pin   = 3;
    IRPyro_device[3].INT_Pin  = 7;
    IRPyro_device[3].address  = 0x67;

    /*-----------------    CONFIGURATION   ------------*/
    IRPyro_device[0].AFE_register    = IRPyro_AFE_configuration; // MASTER, INT, CLK DISABLED
    IRPyro_device[0].read_mode       = 1;
    IRPyro_device[0].number_of_active_channels = 1;              // configures channel 2 for streaming
    IRPyro_device[1].AFE_register    = IRPyro_AFE_configuration; // MASTER, INT, CLK DISABLED
    IRPyro_device[1].read_mode       = 1;
    IRPyro_device[1].number_of_active_channels = 1;              // configures channel 2 for streaming
    IRPyro_device[2].AFE_register    = IRPyro_AFE_configuration; // MASTER, INT, CLK DISABLED
    IRPyro_device[2].read_mode       = 1;
    IRPyro_device[2].number_of_active_channels = 1;              // configures channel 2 for streaming
    IRPyro_device[3].AFE_register    = IRPyro_AFE_configuration; // MASTER, INT, CLK DISABLED
    IRPyro_device[3].read_mode       = 1;
    IRPyro_device[3].number_of_active_channels = 1;              // configures channel 2 for streaming
    IRPyro_demo_board(0);
    UART_PutString(USART2, (uint8_t*)"05 Initialize multiple devices for POLLED CONFIGURATION \n");
    ut02_multiple_sensor_init(IRPyro_device, 4);
}
/**
 * @brief A list of IRPyro devices is declared, all the devices are defined with
the SYNC bit enabled. The data structure is sent to the physical sensors, and
then read back again.
 */
void test06(void)
{
    /*------------------- Memory allocation, initialization ------------------*/
    IRPyro_devices IRPyro_device = {0};
    /*----------------------- --- CONFIGURATION -----  -----------------------*/
    AFE_reg_type IRPyro_AFE_configuration =
    {
        .CLK_OUT = CLK_DISABLE,
        .INT  = INT_ENABLE
    };
    /*-----------------    ADDRESSES   ------------*/
    /* Assuming four sensors on an IRPyro Break out board or demo board*/
    IRPyro_device[0].INT_Port = 1;
    IRPyro_device[0].CS_Port  = 2;
    IRPyro_device[0].CS_Pin   = 1;
    IRPyro_device[0].INT_Pin  = 4;
    IRPyro_device[0].address  = 0x70;

    IRPyro_device[1].CS_Port  = 2;
    IRPyro_device[1].INT_Port = 1;
    IRPyro_device[1].CS_Pin   = 5;
    IRPyro_device[1].INT_Pin  = 5;
    IRPyro_device[1].address  = 0x69;

    IRPyro_device[2].CS_Port  = 2;
    IRPyro_device[2].INT_Port = 1;
    IRPyro_device[2].CS_Pin   = 4;
    IRPyro_device[2].INT_Pin  = 6;
    IRPyro_device[2].address  = 0x68;

    IRPyro_device[3].CS_Port  = 2;
    IRPyro_device[3].INT_Port = 1;
    IRPyro_device[3].CS_Pin   = 3;
    IRPyro_device[3].INT_Pin  = 7;
    IRPyro_device[3].address  = 0x67;

    /*-----------------    CONFIGURATION   ------------*/
    IRPyro_device[0].AFE_register    = IRPyro_AFE_configuration; // MASTER, INT, CLK DISABLED
    IRPyro_device[0].read_mode       = 2;
    IRPyro_device[0].number_of_active_channels = 1;              // configures channel 2 for streaming
    IRPyro_device[1].AFE_register    = IRPyro_AFE_configuration; // MASTER, INT, CLK DISABLED
    IRPyro_device[1].read_mode       = 2;
    IRPyro_device[1].number_of_active_channels = 1;              // configures channel 2 for streaming
    IRPyro_device[2].AFE_register    = IRPyro_AFE_configuration; // MASTER, INT, CLK DISABLED
    IRPyro_device[2].read_mode       = 2;
    IRPyro_device[2].number_of_active_channels = 1;              // configures channel 2 for streaming
    IRPyro_device[3].AFE_register    = IRPyro_AFE_configuration; // MASTER, INT, CLK DISABLED
    IRPyro_device[3].read_mode       = 2;
    IRPyro_device[3].number_of_active_channels = 1;              // configures channel 2 for streaming
    IRPyro_demo_board(0);
    UART_PutString(USART2, (uint8_t*)"06 Initialize multiple devices for DAISY CHAIN CONFIGURATION\n");
    ut02_multiple_sensor_init(IRPyro_device, 4);
}
/**
 * @brief With the data structure defined in 9.1.1.1 an IRPyro sensor is configured.
 * One hour of data is read from the sensor. Each frame counter received is compared
 * with the previous. A missing frame is detected when both numbers are NOT CONSECUTIVE.
 * This event is counted.
 */
void test07(void)
{
    /*------------------ Memory allocation, initialization-------------------*/
    IRPyro_sensor_device_type IRPyro_single_sensor = {0}; // Instance of sensor
    /*-------------------Physical Location ----------------------------------*/
    IRPyro_single_sensor.INT_Port = 1;
    IRPyro_single_sensor.CS_Port  = 2;
    IRPyro_single_sensor.CS_Pin   = 1;
    IRPyro_single_sensor.INT_Pin  = 4;
    /*-------------------Test configuration ---------------------------------*/
    IRPyro_single_sensor.read_mode = 1;                   // Polled mode reading
    IRPyro_single_sensor.address   = 0x08;                // I2C address to configure
    IRPyro_single_sensor.number_of_active_channels = 4;   // configures channel 2 for streaming
    /*-------------------------- board setup ---------------------------------*/
    IRPyro_demo_board(0);
    UART_PutString(USART2, (uint8_t*)"07 READ DATA FROM A SINGLE SENSOR and detect frames missing with the sensor CONFIGURED FOR INTERRUPT.\n");
    ut03_single_sensor_read(&IRPyro_single_sensor);
}
/**
 * @brief With the data structure defined in 9.1.1.2 an IRPyro sensor is configured.
 * One hour of data is read from the sensor. Each frame counter received is compared
 * with the previous. A missing frame is detected when both numbers are NOT CONSECUTIVE.
 * This event is counted.
 */
void test08(void)
{
    /*------------------ Memory allocation, initialization-------------------*/
    IRPyro_sensor_device_type IRPyro_single_sensor = {0}; // Instance of sensor
    /*-------------------Physical Location ----------------------------------*/
    IRPyro_single_sensor.INT_Port = 1;
    IRPyro_single_sensor.CS_Port  = 2;
    IRPyro_single_sensor.CS_Pin   = 1;
    IRPyro_single_sensor.INT_Pin  = 4;
    /*-------------------Test configuration ---------------------------------*/
    IRPyro_single_sensor.read_mode = 1;                   // Polled mode reading
    IRPyro_single_sensor.address   = 0x08;                // I2C address to configure
    IRPyro_single_sensor.number_of_active_channels = 1;   // configures channel 2 for streaming
    /*-------------------------- board setup ---------------------------------*/
    IRPyro_demo_board(0);
    UART_PutString(USART2, (uint8_t*)"08 READ DATA FROM A SINGLE SENSOR and detect frames missing with the sensor CONFIGURED FOR POLLED\n");
    ut03_single_sensor_read(&IRPyro_single_sensor);
}
/**
 * @brief With the data structure defined in 9.1.1.3 an IRPyro sensor is configured.
 * One hour of data is read from the sensor. Each frame counter received is compared
 * with the previous. A missing frame is detected when both numbers are NOT CONSECUTIVE.
 * This event is counted.
 */
void test09(void)
{
    /*------------------- Memory allocation, initialization ------------------*/
    IRPyro_devices IRPyro_device = {0};
    /*----------------------- --- CONFIGURATION -----  -----------------------*/
    AFE_reg_type IRPyro_AFE_configuration =
    {
        .CLK_OUT = CLK_ENABLE,
        .INT     = INT_ENABLE
    };
    AFE_reg_type IRPyro_AFE_Slave =
    {
        .SYNC = SLAVE,
    };

    /*-----------------    ADDRESSES   ------------*/
    /* Assuming four sensors on an IRPyro Break out board or demo board*/
    IRPyro_device[0].INT_Port = 1;
    IRPyro_device[0].CS_Port  = 2;
    IRPyro_device[0].CS_Pin   = 1;
    IRPyro_device[0].INT_Pin  = 4;
    IRPyro_device[0].address  = 0x70;

    IRPyro_device[1].CS_Port  = 2;
    IRPyro_device[1].INT_Port = 1;
    IRPyro_device[1].CS_Pin   = 5;
    IRPyro_device[1].INT_Pin  = 5;
    IRPyro_device[1].address  = 0x69;
    /*-----------------    CONFIGURATION   ------------*/
    IRPyro_device[0].AFE_register    = IRPyro_AFE_configuration; // MASTER
    IRPyro_device[0].read_mode       = 0;
    IRPyro_device[0].number_of_active_channels = 1;
    IRPyro_device[1].AFE_register    = IRPyro_AFE_Slave;         // SLAVE
    IRPyro_device[1].read_mode       = 2;
    IRPyro_device[1].number_of_active_channels = 1;
    /*-------------------------- board setup ---------------------------------*/
    IRPyro_demo_board(0);
    UART_PutString(USART2, (uint8_t*)"09 READ DATA FROM A SINGLE SENSOR and detect frames missing with the sensor CONFIGURED FOR DAISY CHAIN\n");
    ut04_multiple_sensor_read(IRPyro_device, 2);
}
/**
 * @brief With the data structure defined in 9.1.2.1 a four IRPyro sensors are
 * configured. One hour of data is read from the sensors. Each frame counter received
 * is compared with the previous. A missing frame is detected when both numbers are
 * NOT CONSECUTIVE. This event is counted.
 */
void test10(void)
{
    /*------------------- Memory allocation, initialization ------------------*/
    IRPyro_devices IRPyro_device = {0};
    /*----------------------- --- CONFIGURATION -----  -----------------------*/
    AFE_reg_type IRPyro_AFE_Master =
    {
        .S7_S0   = 0,                  // Sets the sampling rate to 1,000 samples per second.
        .LP      = LOW_POWER_DISABLE,  // Low power sets the sampling rate to 166 samples per second.
        .HP      = HP_DISABLE,         // High pass filter enabled
        .C_LP    = LOW_PASS_180,       // Low pass filter set at 180Hz
        .CLK_OUT = CLK_ENABLE,         // Clock output enabled to synchronize other IRPyro sensors
        .SYNC    = MASTER,             // IRPyro set as Master issues the synchronization to SLAVE
        .TEMP    = 0,                  //
        .INT     = INT_ENABLE          // IRPyro indicates data ready enable
    };
    AFE_reg_type IRPyro_AFE_Slave =
    {
        .S7_S0   = 0,                  // Sets the sampling rate to 1,000 samples per second.
        .LP      = LOW_POWER_DISABLE,  // Low power sets the sampling rate to 166 samples per second.
        .HP      = HP_DISABLE,         // High pass filter enabled
        .C_LP    = LOW_PASS_180,       // Low pass filter set at 180Hz
        .CLK_OUT = CLK_DISABLE,        // Clock output enabled to synchronize other IRPyro sensors
        .SYNC    = SLAVE,              // IRPyro set as Slave receives the synchronization from MASTER
        .TEMP    = 0,                  //
        .INT     = INT_ENABLE          // IRPyro indicates data ready enable
    };
    /*-----------------    ADDRESSES   ------------*/
    /* Assuming four sensors on an IRPyro Break out board or demo board*/
    IRPyro_device[0].INT_Port = 1;
    IRPyro_device[0].CS_Port  = 2;
    IRPyro_device[0].CS_Pin   = 1;
    IRPyro_device[0].INT_Pin  = 4;
    IRPyro_device[0].address  = 0x0A;

    IRPyro_device[1].CS_Port  = 2;
    IRPyro_device[1].INT_Port = 1;
    IRPyro_device[1].CS_Pin   = 5;
    IRPyro_device[1].INT_Pin  = 5;
    IRPyro_device[1].address  = 0x0B;

    IRPyro_device[2].CS_Port  = 2;
    IRPyro_device[2].INT_Port = 1;
    IRPyro_device[2].CS_Pin   = 4;
    IRPyro_device[2].INT_Pin  = 6;
    IRPyro_device[2].address  = 0x0C;

    IRPyro_device[3].CS_Port  = 2;
    IRPyro_device[3].INT_Port = 1;
    IRPyro_device[3].CS_Pin   = 3;
    IRPyro_device[3].INT_Pin  = 7;
    IRPyro_device[3].address  = 0x0D;

    /*-----------------    CONFIGURATION   ------------*/
    IRPyro_device[0].AFE_register    = IRPyro_AFE_Master; // MASTER, INT, CLK DISABLED
    IRPyro_device[0].read_mode       = 0;
    IRPyro_device[0].number_of_active_channels = 1;

    IRPyro_device[1].AFE_register    = IRPyro_AFE_Slave; // MASTER, INT, CLK DISABLED
    IRPyro_device[1].read_mode       = 0;
    IRPyro_device[1].number_of_active_channels = 1;

    IRPyro_device[2].AFE_register    = IRPyro_AFE_Slave; // MASTER, INT, CLK DISABLED
    IRPyro_device[2].read_mode       = 0;
    IRPyro_device[2].number_of_active_channels = 1;

    IRPyro_device[3].AFE_register    = IRPyro_AFE_Slave; // MASTER, INT, CLK DISABLED
    IRPyro_device[3].read_mode       = 0;
    IRPyro_device[3].number_of_active_channels = 1;

    UART_PutString(USART2, (uint8_t*)"10 READ DATA FROM MULTIPLE SENSORS and detect frames missing with the sensors CONFIGURED FOR INTERRUPT\n");
    IRPyro_demo_board(0);
    ut04_multiple_sensor_read(IRPyro_device, 4);

}
/**
 * @brief With the data structure defined in 9.1.2.2 a four IRPyro sensors are
configured. One hour of data is read from the sensors. Each frame counter received
is compared with the previous. A missing frame is detected when both numbers are
NOT CONSECUTIVE. This event is counted.
 */
void test11(void)
{

    /*------------------- Memory allocation, initialization ------------------*/
    IRPyro_devices IRPyro_device = {0};
    /*----------------------- --- CONFIGURATION -----  -----------------------*/
    AFE_reg_type IRPyro_AFE_Master =
    {
        .S7_S0 = 0,
        .LP    = LOW_POWER_DISABLE,
        .HP    = HP_DISABLE,
        .C_LP  = LOW_PASS_180,
        .CLK_OUT = CLK_ENABLE,
        .SYNC = MASTER,
        .TEMP = 0,
        .INT  = INT_DISABLE
    };
    AFE_reg_type IRPyro_AFE_Slave =
    {
        .S7_S0 = 0,
        .LP    = LOW_POWER_DISABLE,
        .HP    = HP_DISABLE,
        .C_LP  = LOW_PASS_180,
        .CLK_OUT = CLK_DISABLE,
        .SYNC = SLAVE,
        .TEMP = 0,
        .INT  = INT_DISABLE
    };
    /*-----------------    ADDRESSES   ------------*/
    /* Assuming four sensors on an IRPyro Break out board or demo board*/
    IRPyro_device[0].INT_Port = 1;
    IRPyro_device[0].CS_Port  = 2;
    IRPyro_device[0].CS_Pin   = 1;
    IRPyro_device[0].INT_Pin  = 4;
    IRPyro_device[0].address  = 0x70;

    IRPyro_device[1].CS_Port  = 2;
    IRPyro_device[1].INT_Port = 1;
    IRPyro_device[1].CS_Pin   = 5;
    IRPyro_device[1].INT_Pin  = 5;
    IRPyro_device[1].address  = 0x69;

    IRPyro_device[2].CS_Port  = 2;
    IRPyro_device[2].INT_Port = 1;
    IRPyro_device[2].CS_Pin   = 4;
    IRPyro_device[2].INT_Pin  = 6;
    IRPyro_device[2].address  = 0x68;

    IRPyro_device[3].CS_Port  = 2;
    IRPyro_device[3].INT_Port = 1;
    IRPyro_device[3].CS_Pin   = 3;
    IRPyro_device[3].INT_Pin  = 7;
    IRPyro_device[3].address  = 0x67;

    /*-----------------    CONFIGURATION   ------------*/
    IRPyro_device[0].AFE_register    = IRPyro_AFE_Master; // MASTER, INT, CLK DISABLED
    IRPyro_device[0].read_mode       = 1;
    IRPyro_device[0].number_of_active_channels = 1;

    IRPyro_device[1].AFE_register    = IRPyro_AFE_Slave; // MASTER, INT, CLK DISABLED
    IRPyro_device[1].read_mode       = 1;
    IRPyro_device[1].number_of_active_channels = 1;

    IRPyro_device[2].AFE_register    = IRPyro_AFE_Slave; // MASTER, INT, CLK DISABLED
    IRPyro_device[2].read_mode       = 1;
    IRPyro_device[2].number_of_active_channels = 1;

    IRPyro_device[3].AFE_register    = IRPyro_AFE_Slave; // MASTER, INT, CLK DISABLED
    IRPyro_device[3].read_mode       = 1;
    IRPyro_device[3].number_of_active_channels = 1;

    IRPyro_demo_board(0);
    UART_PutString(USART2, (uint8_t*)"11 READ DATA FROM MULTIPLE SENSORS and detect frames missing with the sensors CONFIGURED FOR POLLED\n");
    ut04_multiple_sensor_read(IRPyro_device, 4);
}
/**
 * @brief With the data structure defined in 9.1.2.3 a four IRPyro sensors are
configured. One hour of data is read from the sensors. Each frame counter received
is compared with the previous. A missing frame is detected when both numbers are
NOT CONSECUTIVE. This event is counted.
 */
void test12(void)
{

    /*------------------- Memory allocation, initialization ------------------*/
    IRPyro_devices IRPyro_device = {0};
    /*----------------------- --- CONFIGURATION -----  -----------------------*/
    AFE_reg_type IRPyro_AFE_Master =
    {
        .S7_S0 = 0,
        .LP    = LOW_POWER_DISABLE,
        .HP    = HP_DISABLE,
        .C_LP  = LOW_PASS_180,
        .CLK_OUT = CLK_ENABLE,
        .SYNC = MASTER,
        .TEMP = 0,
        .INT  = INT_ENABLE
    };
    AFE_reg_type IRPyro_AFE_Slave =
    {
        .S7_S0 = 0,
        .LP    = LOW_POWER_DISABLE,
        .HP    = HP_DISABLE,
        .C_LP  = LOW_PASS_180,
        .CLK_OUT = CLK_DISABLE,
        .SYNC = SLAVE,
        .TEMP = 0,
        .INT  = INT_ENABLE
    };
    /*-----------------    ADDRESSES   ------------*/
    /* Assuming four sensors on an IRPyro Break out board or demo board*/
    IRPyro_device[0].INT_Port = 1;
    IRPyro_device[0].CS_Port  = 2;
    IRPyro_device[0].CS_Pin   = 1;
    IRPyro_device[0].INT_Pin  = 4;
    IRPyro_device[0].address  = 0x70;

    IRPyro_device[1].CS_Port  = 2;
    IRPyro_device[1].INT_Port = 1;
    IRPyro_device[1].CS_Pin   = 5;
    IRPyro_device[1].INT_Pin  = 5;
    IRPyro_device[1].address  = 0x69;

    IRPyro_device[2].CS_Port  = 2;
    IRPyro_device[2].INT_Port = 1;
    IRPyro_device[2].CS_Pin   = 4;
    IRPyro_device[2].INT_Pin  = 6;
    IRPyro_device[2].address  = 0x68;

    IRPyro_device[3].CS_Port  = 2;
    IRPyro_device[3].INT_Port = 1;
    IRPyro_device[3].CS_Pin   = 3;
    IRPyro_device[3].INT_Pin  = 7;
    IRPyro_device[3].address  = 0x67;

    /*-----------------    CONFIGURATION   ------------*/
    IRPyro_device[0].AFE_register    = IRPyro_AFE_Master; // MASTER, INT, CLK DISABLED
    IRPyro_device[0].read_mode       = 0;
    IRPyro_device[0].number_of_active_channels = 1;

    IRPyro_device[1].AFE_register    = IRPyro_AFE_Slave; // MASTER, INT, CLK DISABLED
    IRPyro_device[1].read_mode       = 0;
    IRPyro_device[1].number_of_active_channels = 1;

    IRPyro_device[2].AFE_register    = IRPyro_AFE_Slave; // MASTER, INT, CLK DISABLED
    IRPyro_device[2].read_mode       = 0;
    IRPyro_device[2].number_of_active_channels = 1;

    IRPyro_device[3].AFE_register    = IRPyro_AFE_Slave; // MASTER, INT, CLK DISABLED
    IRPyro_device[3].read_mode       = 0;
    IRPyro_device[3].number_of_active_channels = 1;

    IRPyro_demo_board(0);
    UART_PutString(USART2, (uint8_t*)"12 READ DATA FROM MULTIPLE SENSORS and detect frames missing with the sensors CONFIGURED FOR DAISY CHAIN\n");
    ut04_multiple_sensor_read(IRPyro_device, 4);
}
/**
 * @brief With the data structure defined in 9.1.1.1 an IRPyro sensor is configured.
The following API commands are issued: sampling_rate_set, sampling_rate_get, high_pass_set,
high_pass_get, low_pass_set, low_pass_get, gain_set, and gain_get, power_off.
A sample of readings is taken and the behaviour of the sensor is observed.
 */
void test14(void)
{
    /*------------------ Memory allocation, initialization-------------------*/
    IRPyro_sensor_device_type IRPyro_single_sensor = {0}; // Instance of sensor
    /*-------------------Physical Location ----------------------------------*/
    IRPyro_single_sensor.INT_Port = 1;
    IRPyro_single_sensor.CS_Port  = 2;
    IRPyro_single_sensor.CS_Pin   = 1;
    IRPyro_single_sensor.INT_Pin  = 4;
    /*-------------------Test configuration ---------------------------------*/
    IRPyro_single_sensor.read_mode = 2;                   // DAISY CHAIN CONFIGURATION
    IRPyro_single_sensor.address   = 0x08;                // I2C address to configure
    IRPyro_single_sensor.number_of_active_channels = 1;   // configures channel 2 for streaming
    /*-------------------------- board setup ---------------------------------*/
    IRPyro_demo_board(0);
    UART_PutString(USART2, (uint8_t*)"14 Change sensor POWER CONFIGURATION\n");
    ut06_IOCTL02(&IRPyro_single_sensor);
}
/**
 * @brief With the data structure defined in 9.1.1.1 an IRPyro sensor is configured.
The following API commands are issued: power_sleep, and power_wakeup. A sample of
readings is taken and the behavior of the sensor is observed.
 */
void test15(void)
{
// wake command response
    /* the sensor is configured to sleep and on a wake up event alerts the MCU and
    data is read a more elaborate scenario is putting the MCU to sleep and the
    sensor wakes the device up */
    /*------------------ Memory allocation, initialization-------------------*/
    IRPyro_sensor_device_type IRPyro_single_sensor = {0}; // Instance of sensor
    /*-------------------Physical Location ----------------------------------*/
    IRPyro_single_sensor.INT_Port = 1;
    IRPyro_single_sensor.CS_Port  = 2;
    IRPyro_single_sensor.CS_Pin   = 1;
    IRPyro_single_sensor.INT_Pin  = 4;
    /*-------------------Test configuration ---------------------------------*/
    IRPyro_single_sensor.read_mode = 2;                   // DAISY CHAIN CONFIGURATION
    IRPyro_single_sensor.address   = 0x70;                // I2C address to configure
    IRPyro_single_sensor.number_of_active_channels = 1;   // configures channel 2 for streaming
    /*------------------- Wake up event definition  -------------------------*/
    IRPyro_single_sensor.WUP_register.UHT          = MAX_WUP_THRESHOLD;
    IRPyro_single_sensor.WUP_register.ULT          = SAFE_WUP_THRESHOLD;
    IRPyro_single_sensor.WUP_register.LHT          = MIN_WUP_THRESHOLD;
    IRPyro_single_sensor.WUP_register.LLT          = MIN_WUP_THRESHOLD;
    IRPyro_single_sensor.WUP_register.WT_Threshold = DEFAULT_NO_EVENTS;
    IRPyro_single_sensor.WUP_register.DP0_DP2      = SEL_CH_2;
    IRPyro_single_sensor.WUP_register.CH0_CH2      = SEL_CH_2;
    IRPyro_single_sensor.WUP_register.ST           = SLEEP_MODE_ONE_CH;  // Single channel selected
    /*-------------------------- board setup --------------------------------*/
    IRPyro_demo_board(0);
    UART_PutString(USART2, (uint8_t*)"15 Configure sensor WAKE UP EVENT, SEND TO SLEEP, DETECT WAKE UP \n");
    ut_wake_up_event(&IRPyro_single_sensor);
}
/**
 * @brief With the data structure defined in 9.1.1.1 an IRPyro sensor is configured.
The following API commands are issued: power_off, power_normal, and power_low. A
sample of readings is taken and the behavior of the sensor is observed.
 */
void test16(void)
{
    /*------------------ Memory allocation, initialization-------------------*/
    IRPyro_sensor_device_type IRPyro_single_sensor = {0}; // Instance of sensor
    /*-------------------Physical Location ----------------------------------*/
    IRPyro_single_sensor.INT_Port = 1;
    IRPyro_single_sensor.CS_Port  = 2;
    IRPyro_single_sensor.CS_Pin   = 1;
    IRPyro_single_sensor.INT_Pin  = 4;
    /*-------------------Test configuration ---------------------------------*/
    IRPyro_single_sensor.read_mode = 2;                   // DAISY CHAIN CONFIGURATION
    IRPyro_single_sensor.address   = 0x08;                // I2C address to configure
    IRPyro_single_sensor.number_of_active_channels = 1;   // configures channel 2 for streaming
    /*-------------------------- board setup ---------------------------------*/
    IRPyro_demo_board(0);
    UART_PutString(USART2, (uint8_t*)"16 Change PARAMETERS on the fly\n");
    ut06_IOCTL01(&IRPyro_single_sensor);
}
/** end of Verification plan functions
 * @}
 */
/** end of High Level Unit Test module
 * @}
 */
/* ********** Copyright (c) 2018 _KEMET, Ltd. **********END OF FILE************/
